@@ -10,6 +10,7 @@ from google.protobuf.timestamp_pb2 import Timestamp
 # Imitates how includes in our protobuf files are handled.
 from isolate.connections.grpc.definitions import *
 from isolate.server.definitions import *
+
 from isolate_proto.controller_pb2 import *
 from isolate_proto.controller_pb2_grpc import (
     IsolateControllerServicer,
@@ -37,7 +38,7 @@ def timestamp_from_datetime(datetime: datetime.datetime):
 
 
 def datetime_from_timestamp(timestamp: Timestamp):
-    return timestamp.ToDatetime()
+    return timestamp.ToDatetime(tzinfo=datetime.timezone.utc)
 
 
 def duration_from_timedelta(timedelta: datetime.timedelta):
